@@ -1,9 +1,13 @@
 """Fix antimeridian crossings in GeoJSON objects and shapely geometries."""
 
 from ._implementation import (
+    FixWindingWarning,
     GeoInterface,
     bbox,
+    centroid,
     fix_geojson,
+    fix_line_string,
+    fix_multi_line_string,
     fix_multi_polygon,
     fix_polygon,
     fix_shape,
@@ -12,12 +16,16 @@ from ._implementation import (
 )
 
 __all__ = [
-    "bbox",
-    "fix_polygon",
-    "fix_geojson",
-    "fix_multi_polygon",
-    "fix_shape",
+    "FixWindingWarning",
     "GeoInterface",
+    "bbox",
+    "centroid",
+    "fix_geojson",
+    "fix_line_string",
+    "fix_multi_line_string",
+    "fix_multi_polygon",
+    "fix_polygon",
+    "fix_shape",
     "segment_geojson",
     "segment_shape",
 ]
