@@ -9,7 +9,7 @@ pytest.importorskip("click")
 
 def test_fix(script_runner: ScriptRunner, input_path: Callable[[str], Path]) -> None:
     path = input_path("simple")
-    result = script_runner.run("antimeridian", "fix", str(path))
+    result = script_runner.run(["antimeridian", "fix", str(path)])
     assert result.success
 
 
@@ -17,5 +17,5 @@ def test_segment(
     script_runner: ScriptRunner, input_path: Callable[[str], Path]
 ) -> None:
     path = input_path("simple")
-    result = script_runner.run("antimeridian", "segment", str(path))
+    result = script_runner.run(["antimeridian", "segment", str(path)])
     assert result.success
